pub struct MapRef<'owner, 'elem> { /* private fields */ }Expand description
A reference to a VapourSynth map.
Methods from Deref<Target = Map<'elem>>
Sourcepub fn error(&self) -> Option<Cow<'_, str>>
pub fn error(&self) -> Option<Cow<'_, str>>
Returns the error message contained in the map, if any.
Sourcepub fn value_count(&self, key: &str) -> Result<usize>
pub fn value_count(&self, key: &str) -> Result<usize>
Returns the number of elements associated with a key in a map.
Sourcepub fn value_type(&self, key: &str) -> Result<ValueType>
pub fn value_type(&self, key: &str) -> Result<ValueType>
Retrieves a value type from a map.
Sourcepub fn get<'map, T: Value<'map, 'elem>>(&'map self, key: &str) -> Result<T>
pub fn get<'map, T: Value<'map, 'elem>>(&'map self, key: &str) -> Result<T>
Retrieves a property value.
Sourcepub fn get_iter<'map, T: Value<'map, 'elem>>(
&'map self,
key: &str,
) -> Result<ValueIter<'map, 'elem, T>>
pub fn get_iter<'map, T: Value<'map, 'elem>>( &'map self, key: &str, ) -> Result<ValueIter<'map, 'elem, T>>
Retrieves an iterator over the map values.
Sourcepub fn get_int(&self, key: &str) -> Result<i64>
pub fn get_int(&self, key: &str) -> Result<i64>
Retrieves an integer from a map.
This function retrieves the first value associated with the key.
Sourcepub fn get_int_iter<'map>(
&'map self,
key: &str,
) -> Result<ValueIter<'map, 'elem, i64>>
pub fn get_int_iter<'map>( &'map self, key: &str, ) -> Result<ValueIter<'map, 'elem, i64>>
Retrieves integers from a map.
Sourcepub fn get_int_array(&self, key: &str) -> Result<&[i64]>
pub fn get_int_array(&self, key: &str) -> Result<&[i64]>
Retrieves an array of integers from a map.
This is faster than iterating over a get_int_iter().
Sourcepub fn get_float(&self, key: &str) -> Result<f64>
pub fn get_float(&self, key: &str) -> Result<f64>
Retrieves a floating point number from a map.
This function retrieves the first value associated with the key.
Sourcepub fn get_float_array(&self, key: &str) -> Result<&[f64]>
pub fn get_float_array(&self, key: &str) -> Result<&[f64]>
Retrieves an array of floating point numbers from a map.
This is faster than iterating over a get_float_iter().
Sourcepub fn get_float_iter<'map>(
&'map self,
key: &str,
) -> Result<ValueIter<'map, 'elem, f64>>
pub fn get_float_iter<'map>( &'map self, key: &str, ) -> Result<ValueIter<'map, 'elem, f64>>
Retrieves floating point numbers from a map.
Sourcepub fn get_data(&self, key: &str) -> Result<&[u8]>
pub fn get_data(&self, key: &str) -> Result<&[u8]>
Retrieves data from a map.
This function retrieves the first value associated with the key.
Sourcepub fn get_data_iter<'map>(
&'map self,
key: &str,
) -> Result<ValueIter<'map, 'elem, &'map [u8]>>
pub fn get_data_iter<'map>( &'map self, key: &str, ) -> Result<ValueIter<'map, 'elem, &'map [u8]>>
Retrieves data from a map.
Sourcepub fn get_video_node(&self, key: &str) -> Result<Node<'elem>>
pub fn get_video_node(&self, key: &str) -> Result<Node<'elem>>
Retrieves a node from a map.
This function retrieves the first value associated with the key.
Sourcepub fn get_video_node_iter<'map>(
&'map self,
key: &str,
) -> Result<ValueIter<'map, 'elem, Node<'elem>>>
pub fn get_video_node_iter<'map>( &'map self, key: &str, ) -> Result<ValueIter<'map, 'elem, Node<'elem>>>
Retrieves nodes from a map.
Sourcepub fn get_video_frame(&self, key: &str) -> Result<FrameRef<'elem>>
pub fn get_video_frame(&self, key: &str) -> Result<FrameRef<'elem>>
Retrieves a frame from a map.
This function retrieves the first value associated with the key.
Sourcepub fn get_video_frame_iter<'map>(
&'map self,
key: &str,
) -> Result<ValueIter<'map, 'elem, FrameRef<'elem>>>
pub fn get_video_frame_iter<'map>( &'map self, key: &str, ) -> Result<ValueIter<'map, 'elem, FrameRef<'elem>>>
Retrieves frames from a map.
Sourcepub fn get_function(&self, key: &str) -> Result<Function<'elem>>
pub fn get_function(&self, key: &str) -> Result<Function<'elem>>
Retrieves a function from a map.
This function retrieves the first value associated with the key.